@@ -127,7 +127,7 @@ Out of the box implementation of the Construct without any override will set the
 ---
 
 
-© Copyright 2022 Amazon.com, Inc. or its affiliates. All Rights Reserved.
+© Copyright 2021 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 '''
 import abc
 import builtins
@@ -139,17 +139,15 @@ import jsii
 import publication
 import typing_extensions
 
-from typeguard import check_type
-
 from ._jsii import *
 
 import aws_cdk.aws_cloudfront
 import aws_cdk.aws_wafv2
-import aws_cdk.core
+import constructs
 
 
 class WafwebaclToCloudFront(
-    aws_cdk.core.Construct,
+    constructs.Construct,
     metaclass=jsii.JSIIMeta,
     jsii_type="@aws-solutions-constructs/aws-wafwebacl-cloudfront.WafwebaclToCloudFront",
 ):
@@ -159,12 +157,12 @@ class WafwebaclToCloudFront(
 
     def __init__(
         self,
-        scope: aws_cdk.core.Construct,
+        scope: constructs.Construct,
         id: builtins.str,
         *,
         existing_cloud_front_web_distribution: aws_cdk.aws_cloudfront.Distribution,
         existing_webacl_obj: typing.Optional[aws_cdk.aws_wafv2.CfnWebACL] = None,
-        webacl_props: typing.Optional[typing.Union[aws_cdk.aws_wafv2.CfnWebACLProps, typing.Dict[str, typing.Any]]] = None,
+        webacl_props: typing.Optional[aws_cdk.aws_wafv2.CfnWebACLProps] = None,
     ) -> None:
         '''
         :param scope: - represents the scope for all the resources.
@@ -176,19 +174,6 @@ class WafwebaclToCloudFront(
         :access: public
         :summary: Constructs a new instance of the WafwebaclToCloudFront class.
         '''
-        if __debug__:
-            def stub(
-                scope: aws_cdk.core.Construct,
-                id: builtins.str,
-                *,
-                existing_cloud_front_web_distribution: aws_cdk.aws_cloudfront.Distribution,
-                existing_webacl_obj: typing.Optional[aws_cdk.aws_wafv2.CfnWebACL] = None,
-                webacl_props: typing.Optional[typing.Union[aws_cdk.aws_wafv2.CfnWebACLProps, typing.Dict[str, typing.Any]]] = None,
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
-            check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
-            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = WafwebaclToCloudFrontProps(
             existing_cloud_front_web_distribution=existing_cloud_front_web_distribution,
             existing_webacl_obj=existing_webacl_obj,
@@ -197,12 +182,12 @@ class WafwebaclToCloudFront(
 
         jsii.create(self.__class__, self, [scope, id, props])
 
-    @builtins.property
+    @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="cloudFrontWebDistribution")
     def cloud_front_web_distribution(self) -> aws_cdk.aws_cloudfront.Distribution:
         return typing.cast(aws_cdk.aws_cloudfront.Distribution, jsii.get(self, "cloudFrontWebDistribution"))
 
-    @builtins.property
+    @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="webacl")
     def webacl(self) -> aws_cdk.aws_wafv2.CfnWebACL:
         return typing.cast(aws_cdk.aws_wafv2.CfnWebACL, jsii.get(self, "webacl"))
@@ -223,7 +208,7 @@ class WafwebaclToCloudFrontProps:
         *,
         existing_cloud_front_web_distribution: aws_cdk.aws_cloudfront.Distribution,
         existing_webacl_obj: typing.Optional[aws_cdk.aws_wafv2.CfnWebACL] = None,
-        webacl_props: typing.Optional[typing.Union[aws_cdk.aws_wafv2.CfnWebACLProps, typing.Dict[str, typing.Any]]] = None,
+        webacl_props: typing.Optional[aws_cdk.aws_wafv2.CfnWebACLProps] = None,
     ) -> None:
         '''
         :param existing_cloud_front_web_distribution: The existing CloudFront instance that will be protected with the WAF web ACL. This construct changes the CloudFront distribution by directly manipulating the CloudFormation output, so this must be the Construct and cannot be changed to the Interface (IDistribution)
@@ -234,18 +219,6 @@ class WafwebaclToCloudFrontProps:
         '''
         if isinstance(webacl_props, dict):
             webacl_props = aws_cdk.aws_wafv2.CfnWebACLProps(**webacl_props)
-        if __debug__:
-            def stub(
-                *,
-                existing_cloud_front_web_distribution: aws_cdk.aws_cloudfront.Distribution,
-                existing_webacl_obj: typing.Optional[aws_cdk.aws_wafv2.CfnWebACL] = None,
-                webacl_props: typing.Optional[typing.Union[aws_cdk.aws_wafv2.CfnWebACLProps, typing.Dict[str, typing.Any]]] = None,
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
-            check_type(argname="argument existing_cloud_front_web_distribution", value=existing_cloud_front_web_distribution, expected_type=type_hints["existing_cloud_front_web_distribution"])
-            check_type(argname="argument existing_webacl_obj", value=existing_webacl_obj, expected_type=type_hints["existing_webacl_obj"])
-            check_type(argname="argument webacl_props", value=webacl_props, expected_type=type_hints["webacl_props"])
         self._values: typing.Dict[str, typing.Any] = {
             "existing_cloud_front_web_distribution": existing_cloud_front_web_distribution,
         }
